%define module	tables
%define name 	python-%{module}
%define version 3.0.0
%define release %mkrel 4

Summary: 	Hierarchical datasets in Python
Name: 	 	%{name}
Version: 	%{version}
Release: 	%{release}
Source0: 	https://pypi.python.org/packages/source/t/%{module}/%{module}-%{version}.tar.gz
License: 	BSD
Group: 	 	Development/Python
Url: 	 	http://www.pytables.org
Requires: 	python-numpy >= 1.4.1
Requires:	python-numexpr >= 1.4.1
BuildRequires:	python-numpy >= 1.4.1
BuildRequires:	python-numpy-devel >= 1.4.1
BuildRequires:	python-numexpr >= 1.4.1
BuildRequires: 	hdf5-devel >= 1.6.10
BuildRequires:	bzip2-devel
BuildRequires:	liblzo-devel
BuildRequires:	python-cython >= 0.13
BuildRequires:	python-setuptools
BuildRequires:	pkgconfig(python)

%description
PyTables is a Python package for managing hierarchical datasets
designed to efficiently and easily cope with extremely large amounts
of data. It is built on top of the HDF5 library and the NumPy package
(numarray and Numeric are also supported). PyTables features an
object-oriented interface and performance-critical extensions coded in
C (generated using Pyrex) that make it a fast yet extremely
easy-to-use tool for interactively processing and searching through
very large amounts of data. PyTables also optimizes memory and disk
resources so that data occupies much less space than with other
solutions such as relational or object-oriented databases (especially
when compression is used).

%package	doc
Group:		Development/Python
Summary:	Documentation for PyTables
BuildArch:	noarch

%description doc
The %{name}-doc package contains the documentation related to 
PyTables.

%package -n python3-%{module}
Summary:        Hierarchical datasets in Python 3
Group:          Development/Python
Requires: 	python3-numpy
Requires:	python3-numexpr
BuildRequires:	python3-numpy
BuildRequires:	python3-numexpr
BuildRequires:	python3-setuptools
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-cython

%description -n python3-%{module}
PyTables is a Python 3 package for managing hierarchical datasets
designed to efficiently and easily cope with extremely large amounts
of data. It is built on top of the HDF5 library and the NumPy package
(numarray and Numeric are also supported). PyTables features an
object-oriented interface and performance-critical extensions coded in
C (generated using Pyrex) that make it a fast yet extremely
easy-to-use tool for interactively processing and searching through
very large amounts of data. PyTables also optimizes memory and disk
resources so that data occupies much less space than with other
solutions such as relational or object-oriented databases (especially
when compression is used).


%prep 
%setup -q -n %{module}-%{version}
rm -rf %{py3dir}
cp -a . %{py3dir}
find %{py3dir}/utils -name 'pt*' | xargs sed -i '1s|^#!/usr/bin/env python|#!%{__python3}|'

%build
export LIBS="dl m"
CFLAGS="%{optflags}" %{__python} setup.py build

pushd %{py3dir}
CFLAGS="%{optflags}" %{__python3} setup.py build
popd

%install
chmod -x examples/check_examples.sh
for i in utils/*; do sed -i 's|bin/env |bin/|' $i; done

pushd %{py3dir}
%{__python3} setup.py install -O1 --skip-build --root %{buildroot}
mv %{buildroot}/usr/bin/pt2to3 %{buildroot}/usr/bin/pt2to33
mv %{buildroot}/usr/bin/ptdump %{buildroot}/usr/bin/ptdump3
mv %{buildroot}/usr/bin/ptrepack %{buildroot}/usr/bin/ptrepack3
popd

%{__python} setup.py install -O1 --skip-build --root=%{buildroot} 


%check
pushd %{py3dir}
libdir=`ls build/|grep lib`
export PYTHONPATH=`pwd`/build/$libdir
echo "import tables; tables.test()" > bench/check_all.py
%{__python3} bench/check_all.py
popd

libdir=`ls build/|grep lib`
export PYTHONPATH=`pwd`/build/$libdir
echo "import tables; tables.test()" > bench/check_all.py
%{__python} bench/check_all.py


%files
%doc *.txt LICENSES
%{_bindir}/pt2to3
%{_bindir}/ptdump
%{_bindir}/ptrepack
%{python_sitearch}/%{module}
%{python_sitearch}/%{module}-%{version}-py*.egg-info

%files doc
%doc examples/
%doc doc/html/

%files -n python3-%{module}
%doc *.txt LICENSES
%{_bindir}/pt2to33
%{_bindir}/ptdump3
%{_bindir}/ptrepack3
%{python3_sitearch}/%{module}
%{python3_sitearch}/%{module}-%{version}-py*.egg-info



%changelog
* Tue Oct 22 2013 umeabot <umeabot> 3.0.0-4.mga4
+ Revision: 544578
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 3.0.0-3.mga4
+ Revision: 499522
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Jul 16 2013 fwang <fwang> 3.0.0-2.mga4
+ Revision: 455002
- rebuild for new hdf5

* Sat Jul 06 2013 philippem <philippem> 3.0.0-1.mga4
+ Revision: 450396
- Update to 3.0.0 , add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 2.3.1-2.mga3
+ Revision: 379554
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Oct 30 2011 lebedov <lebedov> 2.3.1-1.mga2
+ Revision: 159903
- Update to 2.3.1.

* Mon Sep 26 2011 lebedov <lebedov> 2.3-1.mga2
+ Revision: 148858
- Update to 2.3.

* Sun Sep 18 2011 lebedov <lebedov> 2.2.1-1.mga2
+ Revision: 145203
- Update spec file.
- imported package python-tables

